@@ -3,7 +3,7 @@ use std::convert::TryFrom;
 use std::convert::TryInto;
 
 use arrayvec::ArrayVec;
-use smartstring::alias::String;
+use compact_str::CompactStr;
 
 use crate::genre::Genre;
 use crate::Error;
@@ -14,7 +14,7 @@ use crate::TitleType;
 /// Represents a movie from IMDB.  Pared down from [Title] based on fields that make sense for movies.
 pub struct Movie {
 	pub imdb_id: u32,
-	pub title: String,
+	pub title: CompactStr,
 	pub is_adult: bool,
 	pub year: u16,
 	pub runtime_minutes: Option<u16>,
@@ -26,7 +26,7 @@ impl Movie {
 	pub(crate) fn new(imdb_id: u32, title: &str, is_adult: bool, year: u16, runtime_minutes: Option<u16>, genres: &[Genre]) -> Self {
 		Self{
 			imdb_id,
-			title: String::from(title),
+			title: CompactStr::new(title),
 			is_adult,
 			year,
 			runtime_minutes,
